==> blesta-5.10.2.zip: blesta/plugins/domains/language/nl_nl/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.nl_nl
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.getfilters.field_service_meta'] = 'Domeinnaam';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = 'Elke';
$lang['AdminMain.domains.action.field_client'] = 'Klant';
$lang['AdminMain.domains.action.field_nameservers'] = 'Nameservers';
$lang['AdminMain.domains.action.field_years'] = 'Jaren';
$lang['AdminMain.index.field_actionsubmit'] = 'Stuur  in';
$lang['AdminMain.index.domain_push_to_client'] = 'Push naar klant';
$lang['AdminMain.index.update_nameservers'] = 'Nameservers bijwerken';
$lang['AdminMain.index.domain_renewal'] = 'Domein vernieuwen';
$lang['AdminMain.index.change_auto_renewal'] = 'Auto verlengen';
$lang['AdminMain.index.text_off'] = 'Uit';
$lang['AdminMain.index.text_on'] = 'Op';
$lang['AdminMain.index.text_never'] = 'Nooit';
$lang['AdminMain.index.no_results'] = 'Er zijn geen diensten met deze status.';
$lang['AdminMain.index.confirm_delete'] = 'Weet je zeker dat je deze service wilt verwijderen?';
$lang['AdminMain.index.option_delete'] = 'Verwijder';
$lang['AdminMain.index.option_manage'] = 'Beheer';
$lang['AdminMain.index.option_parent'] = 'Ouder';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = 'Nieuw domein';
$lang['AdminMain.index.category_canceled'] = 'Geannuleerd';
$lang['AdminMain.index.category_suspended'] = 'Geschorst';
$lang['AdminMain.index.category_pending'] = 'In afwachting van';
$lang['AdminMain.index.category_active'] = 'Actief';
$lang['AdminMain.index.heading_options'] = 'Opties';
$lang['AdminMain.index.heading_datecanceled'] = 'Datum Geannuleerd';
$lang['AdminMain.index.heading_datesuspended'] = 'Datum geschorst';
$lang['AdminMain.index.heading_dateexpires'] = 'Datum verloopt';
$lang['AdminMain.index.heading_daterenews'] = 'Datum Verlenging';
$lang['AdminMain.index.heading_datecreated'] = 'Datum gemaakt';
$lang['AdminMain.index.heading_term'] = 'Term';
$lang['AdminMain.index.heading_domain'] = 'Domein';
$lang['AdminMain.index.heading_status'] = 'Status';
$lang['AdminMain.index.heading_addons'] = 'Toevoegingen';
$lang['AdminMain.index.boxtitle_domains'] = 'Domeinen';
$lang['AdminMain.index.page_title'] = 'Klant #%1$s Domeinen';
$lang['AdminMain.!success.domains_pushed'] = 'De geselecteerde domeinen zijn met succes naar de nieuwe client gepushed.';
$lang['AdminMain.!success.update_nameservers'] = 'De domeinnaamservers zijn bijgewerkt!';
$lang['AdminMain.!success.domain_renewal'] = 'Het domein is vernieuwd!';
$lang['AdminMain.!success.change_auto_renewal'] = 'De automatische verlenging van domeinen is bijgewerkt!';
$lang['AdminMain.getmodulefields.auto_choose'] = '-- Kies Automatisch';
$lang['AdminMain.edit.title_basic_options'] = 'Basisopties';
$lang['AdminMain.edit.title_actions'] = 'Acties';
$lang['AdminMain.edit.title_domain_information'] = 'Domeininformatie';
$lang['AdminMain.edit.term_years'] = '%1$s Jaren';
$lang['AdminMain.edit.term_year'] = '%1$s Jaar';
$lang['AdminMain.edit.term_months'] = '%1$s Maanden';
$lang['AdminMain.edit.term_month'] = '%1$s Maand';
$lang['AdminMain.edit.term_weeks'] = '%1$s Weken';
$lang['AdminMain.edit.term_week'] = '%1$s Week';
$lang['AdminMain.edit.term_days'] = '%1$s Dagen';
$lang['AdminMain.edit.term_day'] = '%1$s Dag';
$lang['AdminMain.edit.text_date_canceled'] = 'Annuleringsdatum:';
$lang['AdminMain.edit.text_date_suspended'] = 'Schorsingsdatum:';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Laatste verlengde datum:';
$lang['AdminMain.edit.text_never'] = 'Nooit';
$lang['AdminMain.edit.text_date_expires'] = 'Datum verloopt:';
$lang['AdminMain.edit.text_date_renews'] = 'Datum wordt vernieuwd:';
$lang['AdminMain.edit.text_date_added'] = 'Datum gemaakt:';
$lang['AdminMain.edit.text_status'] = 'Status:';
$lang['AdminMain.edit.text_years'] = 'Geregistreerde jaren:';
$lang['AdminMain.edit.text_registrar'] = 'Griffier:';
$lang['AdminMain.edit.text_domain'] = 'Domein:';
$lang['AdminMain.edit.field_edit_service'] = 'Bewerk service';
$lang['AdminMain.edit.field_activate'] = 'Activeer';
$lang['AdminMain.edit.field_submit'] = 'Update';
$lang['AdminMain.edit.field_notify_order'] = 'E-mail ter bevestiging van bestelling verzenden wanneer geactiveerd';
$lang['AdminMain.edit.field_use_module'] = 'Gebruik module';
$lang['AdminMain.edit.field_module'] = 'Module registratiehouder';
$lang['AdminMain.edit.field_client'] = 'Klant';
$lang['AdminMain.edit.field_ns5'] = 'Naamserver 5';
$lang['AdminMain.edit.field_ns4'] = 'Naamserver 4';
$lang['AdminMain.edit.field_ns3'] = 'Naamserver 3';
$lang['AdminMain.edit.field_ns2'] = 'Naamserver 2';
$lang['AdminMain.edit.field_ns1'] = 'Naamserver 1';
$lang['AdminMain.edit.field_auto_renewal'] = 'Automatisch vernieuwen inschakelen';
$lang['AdminMain.edit.field_years'] = 'Jaren';
$lang['AdminMain.edit.field_action'] = 'Actie';
$lang['AdminMain.edit.link_viewclient'] = 'Bekijk klant';
$lang['AdminMain.edit.boxtitle_edit'] = 'Domein bewerken: %1$s';
$lang['AdminMain.edit.boxtitle_client'] = 'Klant #%1$s';
$lang['AdminMain.add_confirmation.discount'] = 'Korting:';
$lang['AdminMain.add_confirmation.subtotal'] = 'Subtotaal:';
$lang['AdminMain.add_confirmation.price'] = 'Prijs';
$lang['AdminMain.add_confirmation.qty'] = 'Hoeveelheid';
$lang['AdminMain.add_confirmation.description'] = 'Beschrijving';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Overdracht';
$lang['AdminMain.add_confirmation.type_register'] = 'Registratie';
$lang['AdminMain.add_confirmation.field_edit'] = 'Bewerk';
$lang['AdminMain.add_confirmation.field_add'] = 'Domein toevoegen';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Update';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'kortingscode';
$lang['AdminMain.add_confirmation.field_price'] = 'Prijs:';
$lang['AdminMain.add_confirmation.field_type'] = 'Type:';
$lang['AdminMain.add_confirmation.field_years'] = 'Jaren:';
$lang['AdminMain.add_confirmation.field_domain'] = 'Domein:';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Geen';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Ja';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'E-mail ter bevestiging van bestelling verzenden:';
$lang['AdminMain.add_confirmation.field_module'] = 'Registratiemodule:';
$lang['AdminMain.add_confirmation.field_status'] = 'Status:';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Niet factureren';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Toevoegen aan factuur %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Nieuwe factuur maken';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Factuurmethode:';
$lang['AdminMain.add.edit_package_pricing'] = 'Prijzen bewerken';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (verlengt @ %3$s)';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = 'Geselecteerde bestelling';
$lang['AdminMain.add.term_years'] = '%1$s Jaren';
$lang['AdminMain.add.term_year'] = '%1$s Jaar';
$lang['AdminMain.add.term_months'] = '%1$s Maanden';
$lang['AdminMain.add.term_month'] = '%1$s Maand';
$lang['AdminMain.add.term_weeks'] = '%1$s Weken';
$lang['AdminMain.add.term_week'] = '%1$s Week';
$lang['AdminMain.add.term_days'] = '%1$s Dagen';
$lang['AdminMain.add.term_day'] = '%1$s Dag';
$lang['AdminMain.add.text_domain_unavailable'] = 'Niet beschikbaar';
$lang['AdminMain.add.text_domain_available'] = 'Beschikbaar';
$lang['AdminMain.add.heading_options'] = 'Opties';
$lang['AdminMain.add.heading_status'] = 'Status';
$lang['AdminMain.add.heading_domain'] = 'Domein';
$lang['AdminMain.add.title_registrar_options'] = 'Opties voor registratiehouder';
$lang['AdminMain.add.title_basic_options'] = 'Basisopties';
$lang['AdminMain.add.title_search_results'] = 'Zoekresultaten';
$lang['AdminMain.add.field_notify_order'] = 'E-mail ter bevestiging van bestelling verzenden wanneer geactiveerd';
$lang['AdminMain.add.field_use_module'] = 'Provisioneer het domein met behulp van de registrarmodule wanneer deze is geactiveerd';
$lang['AdminMain.add.field_module'] = 'Module registratiehouder';
$lang['AdminMain.add.field_status'] = 'Status';
$lang['AdminMain.add.field_years'] = 'Jaren';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Niet factureren';
$lang['AdminMain.add.field_invoice_method_append'] = 'Toevoegen aan bestaande factuur';
$lang['AdminMain.add.field_invoice_method_create'] = 'Nieuwe factuur maken';
$lang['AdminMain.add.field_invoice_method'] = 'Factuurmethode';
$lang['AdminMain.add.field_submit'] = 'Ga verder';
$lang['AdminMain.add.field_lookup'] = 'Beschikbaarheid controleren';
$lang['AdminMain.add.field_add'] = 'Domein toevoegen';
$lang['AdminMain.add.field_register'] = 'Registreer';
$lang['AdminMain.add.field_transfer'] = 'Overdracht';
$lang['AdminMain.add.link_viewclient'] = 'Bekijk klant';
$lang['AdminMain.add.boxtitle_add'] = 'Domein toevoegen: %1$s';
$lang['AdminMain.add.boxtitle_client'] = 'Klant #%1$s';
$lang['AdminMain.index.unparent'] = 'Prijs loskoppelen en opnieuw instellen';
$lang['AdminMain.!error.unsupported_domain'] = 'De domeinnaam wordt niet ondersteund.';
$lang['AdminMain.!success.service_edited'] = 'Het domein is succesvol bijgewerkt!';
$lang['AdminMain.!success.domain_add'] = 'Het domein is succesvol toegevoegd!';
$lang['AdminMain.!success.domain_transfer'] = 'Het domein is succesvol verhuisd!';
$lang['AdminMain.!success.domain_register'] = 'Het domein is succesvol geregistreerd!';
$lang['AdminMain.!success.domains_unparented'] = 'De geselecteerde domeinen zijn verwijderd uit hun bovenliggende services en de prijs is met succes gereset!';
$lang['AdminMain.edit.text_registration_date'] = 'Datum geregistreerd:';
$lang['AdminMain.index.text_date_added'] = 'Datum toegevoegd:';
$lang['AdminMain.index.heading_dateregistration'] = 'Datum geregistreerd';
$lang['AdminMain.index.heading_registrar'] = 'Registrator';
$lang['AdminMain.!success.domain_registrar_updated'] = 'De domeinregistrar is bijgewerkt!';

==> blesta-5.11.4.zip: blesta/plugins/domains/language/nl_nl/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.nl_nl
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.getfilters.field_service_meta'] = 'Domeinnaam';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = 'Elke';
$lang['AdminMain.domains.action.field_client'] = 'Klant';
$lang['AdminMain.domains.action.field_nameservers'] = 'Nameservers';
$lang['AdminMain.domains.action.field_years'] = 'Jaren';
$lang['AdminMain.index.field_actionsubmit'] = 'Stuur  in';
$lang['AdminMain.index.domain_push_to_client'] = 'Push naar klant';
$lang['AdminMain.index.update_nameservers'] = 'Nameservers bijwerken';
$lang['AdminMain.index.domain_renewal'] = 'Domein vernieuwen';
$lang['AdminMain.index.change_auto_renewal'] = 'Auto verlengen';
$lang['AdminMain.index.text_off'] = 'Uit';
$lang['AdminMain.index.text_on'] = 'Op';
$lang['AdminMain.index.text_never'] = 'Nooit';
$lang['AdminMain.index.no_results'] = 'Er zijn geen diensten met deze status.';
$lang['AdminMain.index.confirm_delete'] = 'Weet je zeker dat je deze service wilt verwijderen?';
$lang['AdminMain.index.option_delete'] = 'Verwijder';
$lang['AdminMain.index.option_manage'] = 'Beheer';
$lang['AdminMain.index.option_parent'] = 'Ouder';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = 'Nieuw domein';
$lang['AdminMain.index.category_canceled'] = 'Geannuleerd';
$lang['AdminMain.index.category_suspended'] = 'Geschorst';
$lang['AdminMain.index.category_pending'] = 'In afwachting van';
$lang['AdminMain.index.category_active'] = 'Actief';
$lang['AdminMain.index.heading_options'] = 'Opties';
$lang['AdminMain.index.heading_datecanceled'] = 'Datum Geannuleerd';
$lang['AdminMain.index.heading_datesuspended'] = 'Datum geschorst';
$lang['AdminMain.index.heading_dateexpires'] = 'Datum verloopt';
$lang['AdminMain.index.heading_daterenews'] = 'Datum Verlenging';
$lang['AdminMain.index.heading_datecreated'] = 'Datum gemaakt';
$lang['AdminMain.index.heading_term'] = 'Term';
$lang['AdminMain.index.heading_domain'] = 'Domein';
$lang['AdminMain.index.heading_status'] = 'Status';
$lang['AdminMain.index.heading_addons'] = 'Toevoegingen';
$lang['AdminMain.index.boxtitle_domains'] = 'Domeinen';
$lang['AdminMain.index.page_title'] = 'Klant #%1$s Domeinen';
$lang['AdminMain.!success.domains_pushed'] = 'De geselecteerde domeinen zijn met succes naar de nieuwe client gepushed.';
$lang['AdminMain.!success.update_nameservers'] = 'De domeinnaamservers zijn bijgewerkt!';
$lang['AdminMain.!success.domain_renewal'] = 'Het domein is vernieuwd!';
$lang['AdminMain.!success.change_auto_renewal'] = 'De automatische verlenging van domeinen is bijgewerkt!';
$lang['AdminMain.getmodulefields.auto_choose'] = '-- Kies Automatisch';
$lang['AdminMain.edit.title_basic_options'] = 'Basisopties';
$lang['AdminMain.edit.title_actions'] = 'Acties';
$lang['AdminMain.edit.title_domain_information'] = 'Domeininformatie';
$lang['AdminMain.edit.term_years'] = '%1$s Jaren';
$lang['AdminMain.edit.term_year'] = '%1$s Jaar';
$lang['AdminMain.edit.term_months'] = '%1$s Maanden';
$lang['AdminMain.edit.term_month'] = '%1$s Maand';
$lang['AdminMain.edit.term_weeks'] = '%1$s Weken';
$lang['AdminMain.edit.term_week'] = '%1$s Week';
$lang['AdminMain.edit.term_days'] = '%1$s Dagen';
$lang['AdminMain.edit.term_day'] = '%1$s Dag';
$lang['AdminMain.edit.text_date_canceled'] = 'Annuleringsdatum:';
$lang['AdminMain.edit.text_date_suspended'] = 'Schorsingsdatum:';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Laatste verlengde datum:';
$lang['AdminMain.edit.text_never'] = 'Nooit';
$lang['AdminMain.edit.text_date_expires'] = 'Datum verloopt:';
$lang['AdminMain.edit.text_date_renews'] = 'Datum wordt vernieuwd:';
$lang['AdminMain.edit.text_date_added'] = 'Datum gemaakt:';
$lang['AdminMain.edit.text_status'] = 'Status:';
$lang['AdminMain.edit.text_years'] = 'Geregistreerde jaren:';
$lang['AdminMain.edit.text_registrar'] = 'Griffier:';
$lang['AdminMain.edit.text_domain'] = 'Domein:';
$lang['AdminMain.edit.field_edit_service'] = 'Bewerk service';
$lang['AdminMain.edit.field_activate'] = 'Activeer';
$lang['AdminMain.edit.field_submit'] = 'Update';
$lang['AdminMain.edit.field_notify_order'] = 'E-mail ter bevestiging van bestelling verzenden wanneer geactiveerd';
$lang['AdminMain.edit.field_use_module'] = 'Gebruik module';
$lang['AdminMain.edit.field_module'] = 'Module registratiehouder';
$lang['AdminMain.edit.field_client'] = 'Klant';
$lang['AdminMain.edit.field_ns5'] = 'Naamserver 5';
$lang['AdminMain.edit.field_ns4'] = 'Naamserver 4';
$lang['AdminMain.edit.field_ns3'] = 'Naamserver 3';
$lang['AdminMain.edit.field_ns2'] = 'Naamserver 2';
$lang['AdminMain.edit.field_ns1'] = 'Naamserver 1';
$lang['AdminMain.edit.field_auto_renewal'] = 'Automatisch vernieuwen inschakelen';
$lang['AdminMain.edit.field_years'] = 'Jaren';
$lang['AdminMain.edit.field_action'] = 'Actie';
$lang['AdminMain.edit.link_viewclient'] = 'Bekijk klant';
$lang['AdminMain.edit.boxtitle_edit'] = 'Domein bewerken: %1$s';
$lang['AdminMain.edit.boxtitle_client'] = 'Klant #%1$s';
$lang['AdminMain.add_confirmation.discount'] = 'Korting:';
$lang['AdminMain.add_confirmation.subtotal'] = 'Subtotaal:';
$lang['AdminMain.add_confirmation.price'] = 'Prijs';
$lang['AdminMain.add_confirmation.qty'] = 'Hoeveelheid';
$lang['AdminMain.add_confirmation.description'] = 'Beschrijving';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Overdracht';
$lang['AdminMain.add_confirmation.type_register'] = 'Registratie';
$lang['AdminMain.add_confirmation.field_edit'] = 'Bewerk';
$lang['AdminMain.add_confirmation.field_add'] = 'Domein toevoegen';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Update';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'kortingscode';
$lang['AdminMain.add_confirmation.field_price'] = 'Prijs:';
$lang['AdminMain.add_confirmation.field_type'] = 'Type:';
$lang['AdminMain.add_confirmation.field_years'] = 'Jaren:';
$lang['AdminMain.add_confirmation.field_domain'] = 'Domein:';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Geen';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Ja';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'E-mail ter bevestiging van bestelling verzenden:';
$lang['AdminMain.add_confirmation.field_module'] = 'Registratiemodule:';
$lang['AdminMain.add_confirmation.field_status'] = 'Status:';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Niet factureren';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Toevoegen aan factuur %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Nieuwe factuur maken';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Factuurmethode:';
$lang['AdminMain.add.edit_package_pricing'] = 'Prijzen bewerken';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (verlengt @ %3$s)';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = 'Geselecteerde bestelling';
$lang['AdminMain.add.term_years'] = '%1$s Jaren';
$lang['AdminMain.add.term_year'] = '%1$s Jaar';
$lang['AdminMain.add.term_months'] = '%1$s Maanden';
$lang['AdminMain.add.term_month'] = '%1$s Maand';
$lang['AdminMain.add.term_weeks'] = '%1$s Weken';
$lang['AdminMain.add.term_week'] = '%1$s Week';
$lang['AdminMain.add.term_days'] = '%1$s Dagen';
$lang['AdminMain.add.term_day'] = '%1$s Dag';
$lang['AdminMain.add.text_domain_unavailable'] = 'Niet beschikbaar';
$lang['AdminMain.add.text_domain_available'] = 'Beschikbaar';
$lang['AdminMain.add.heading_options'] = 'Opties';
$lang['AdminMain.add.heading_status'] = 'Status';
$lang['AdminMain.add.heading_domain'] = 'Domein';
$lang['AdminMain.add.title_registrar_options'] = 'Opties voor registratiehouder';
$lang['AdminMain.add.title_basic_options'] = 'Basisopties';
$lang['AdminMain.add.title_search_results'] = 'Zoekresultaten';
$lang['AdminMain.add.field_notify_order'] = 'E-mail ter bevestiging van bestelling verzenden wanneer geactiveerd';
$lang['AdminMain.add.field_use_module'] = 'Provisioneer het domein met behulp van de registrarmodule wanneer deze is geactiveerd';
$lang['AdminMain.add.field_module'] = 'Module registratiehouder';
$lang['AdminMain.add.field_status'] = 'Status';
$lang['AdminMain.add.field_years'] = 'Jaren';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Niet factureren';
$lang['AdminMain.add.field_invoice_method_append'] = 'Toevoegen aan bestaande factuur';
$lang['AdminMain.add.field_invoice_method_create'] = 'Nieuwe factuur maken';
$lang['AdminMain.add.field_invoice_method'] = 'Factuurmethode';
$lang['AdminMain.add.field_submit'] = 'Ga verder';
$lang['AdminMain.add.field_lookup'] = 'Beschikbaarheid controleren';
$lang['AdminMain.add.field_add'] = 'Domein toevoegen';
$lang['AdminMain.add.field_register'] = 'Registreer';
$lang['AdminMain.add.field_transfer'] = 'Overdracht';
$lang['AdminMain.add.link_viewclient'] = 'Bekijk klant';
$lang['AdminMain.add.boxtitle_add'] = 'Domein toevoegen: %1$s';
$lang['AdminMain.add.boxtitle_client'] = 'Klant #%1$s';
$lang['AdminMain.index.unparent'] = 'Prijs loskoppelen en opnieuw instellen';
$lang['AdminMain.!error.unsupported_domain'] = 'De domeinnaam wordt niet ondersteund.';
$lang['AdminMain.!success.service_edited'] = 'Het domein is succesvol bijgewerkt!';
$lang['AdminMain.!success.domain_add'] = 'Het domein is succesvol toegevoegd!';
$lang['AdminMain.!success.domain_transfer'] = 'Het domein is succesvol verhuisd!';
$lang['AdminMain.!success.domain_register'] = 'Het domein is succesvol geregistreerd!';
$lang['AdminMain.!success.domains_unparented'] = 'De geselecteerde domeinen zijn verwijderd uit hun bovenliggende services en de prijs is met succes gereset!';
$lang['AdminMain.edit.text_registration_date'] = 'Datum geregistreerd:';
$lang['AdminMain.index.text_date_added'] = 'Datum toegevoegd:';
$lang['AdminMain.index.heading_dateregistration'] = 'Datum geregistreerd';
$lang['AdminMain.index.heading_registrar'] = 'Registrator';
$lang['AdminMain.!success.domain_registrar_updated'] = 'De domeinregistrar is bijgewerkt!';
$lang['AdminMain.edit.field_registration_date'] = 'Registratiedatum wijzigen';
$lang['AdminMain.edit.field_expiration_date'] = 'Verloopdatum wijzigen';
$lang['AdminMain.!success.change_registration_date'] = 'De registratiedatum van het domein is bijgewerkt!';
$lang['AdminMain.!success.change_expiration_date'] = 'De vervaldatum van het domein is bijgewerkt!';
